/*****************************************************************************
*
* hstimer.h     
* Copyright 1999,2003 William Garrison
*
* - High speed timer class
* - Can be used to abstract OS specific timer functions
* - STATIC, so just init() it, and anybody can use it, any scope
*****************************************************************************/

#ifndef __hsTimer_h__
#define __hsTimer_h__

#ifndef WIN32
#include <sys/types.h>     // For int64_t
#endif

namespace MobyDisk {

////////////////////////////////////////////////////////////////////////////////
//
// Store time as a 64 bit number
// - This is used to store the current time as returned by getTime()
// - It is not guaranteed to be in any particular unit
// - Use getElapsed() to get a time in milliseconds
////////////////////////////////////////////////////////////////////////////////
#ifdef WIN32
   typedef __int64 hsTime;
#else
   typedef int64_t hsTime;
#endif

////////////////////////////////////////////////////////////////////////////////
//
// Class for high-speed timer
// - Init must be called before any other operation
// - All members are static.  No instance is needed
// - Times are returned as an hsTime, which is an unspecified format
// - Time in milliseconds is returned by getElapsed()
//
// Example:
//    hsTimer::init();
//    hsTime start = hsTimer::getTime();
//       ... do some work here ...
//    double ElapsedMilliseconds = hsTimer::getElapsed(start);
//
////////////////////////////////////////////////////////////////////////////////
class hsTimer
{
private:
   static hsTime     ticksPerMS;                // Ticks per millisecond
                                                // (This is OS specific)

public:
   static void    init();                       // Intialize timer class
   static hsTime  getTime();                    // Get current time as an hsTime
   static double  getElapsed(                   // Elapsed time in milliseconds
      hsTime start,                             // - Start time
      hsTime stop=-1);                          // - Defaults to current time
   static void    hsDelay(double millisecs);    // Delay as accurately as possible
   static void    niceDelay(double millisecs);  // Delay while yielding CPU
};

} // namespace MobyDisk

#endif // __hsTimer_h__
